'use strict';
import * as fs from 'node:fs';
import { SfCommand, Flags } from '@salesforce/sf-plugins-core';
import { Messages } from '@salesforce/core';
import { TO_DEFAULT_VALUE } from '../../constants/gitConstants.js';
import { extractTestClasses } from '../../service/extractTestClasses.js';
Messages.importMessagesDirectoryFromMetaUrl(import.meta.url);
const messages = Messages.loadMessages('apex-tests-git-delta', 'delta');
export default class ApexTestDelta extends SfCommand {
    static summary = messages.getMessage('summary');
    static description = messages.getMessage('description');
    static examples = messages.getMessages('examples');
    static flags = {
        'to': Flags.string({
            char: 't',
            summary: messages.getMessage('flags.to.summary'),
            required: true,
            default: TO_DEFAULT_VALUE,
        }),
        'from': Flags.string({
            char: 'f',
            summary: messages.getMessage('flags.from.summary'),
            required: true,
        }),
        'regular-expression': Flags.file({
            char: 'e',
            summary: messages.getMessage('flags.regular-expression.summary'),
            required: true,
            exists: true,
            default: 'regex.txt',
        }),
        'output': Flags.file({
            summary: messages.getMessage('flags.output.summary'),
            required: true,
            exists: false,
            default: 'runTests.txt',
        }),
    };
    async run() {
        const { flags } = await this.parse(ApexTestDelta);
        const toGitRef = flags['to'];
        const fromGitRef = flags['from'];
        const regExFile = flags['regular-expression'];
        const output = flags['output'];
        const deltaTests = extractTestClasses(fromGitRef, toGitRef, regExFile);
        this.log(deltaTests);
        fs.writeFileSync(output, deltaTests);
        return { tests: deltaTests };
    }
}
//# sourceMappingURL=delta.js.map